;; Generated package description from srht.el  -*- no-byte-compile: t -*-
(define-package "srht" "0.4.0.20240506.104337" "Sourcehut" '((emacs "27.1") (plz "0.7") (transient "0.4.3")) :commit "e7ee980ff7713c58fa31d620c5679d78c7dde947" :authors '(("Aleksandr Vityazev" . "avityazev@posteo.org")) :maintainer '("Aleksandr Vityazev" . "avityazev@posteo.org") :keywords '("comm" "vc") :url "https://sr.ht/~akagi/srht.el/")
